from django.urls import path

from c123_kubernetes.api.postgres.views import PgClusterCreateView, ExportPgNode, ImportPgNode, \
    BackupPgNode, PgStandbyAddView, RestoreBackupPgNode, AddpgDB, CheckPgDatabaseName, \
    CheckPgDatabaseSize, DropPgPod, Exportk8sPgDatabase, RestoreBackupPgDB, DropPgDatabase, DropPgCluster, \
    checkDiskSpace
from c123_kubernetes.api.mongo.views import (c123_k8s_DropMongoPodView, DumpMongoNode_k8s, RestoreDumpMongoNode_k8s,
                                             MongoClusterCreateView)
from c123_kubernetes.api.views import GetUnusedNodeIp, CheckPathExists, CheckPortExists

urlpatterns = [
    # general validation
    path("get_unused_node_ip/", GetUnusedNodeIp, name="get_unused_node_ip"),
    path("check_path_exists/", CheckPathExists, name = "check_path_exists"),
    path("check_port_exists/", CheckPortExists, name = "check_port_exists"),
    path("check_disk_space/", checkDiskSpace, name = "check_disk_space"),

    # postgres
    path("create_pg_primary/", PgClusterCreateView.as_view(), name="create_pg_primary"),
    path("create_pg_standby/", PgStandbyAddView.as_view(), name="create_pg_standby"),
    path("drop_pg_cluster/", DropPgCluster, name="drop_pg_cluster"),
    path("drop_pg_pod/", DropPgPod, name="drop_pg_pod"),
    path("export_pg_pod/", ExportPgNode, name="export_pg_pod"),
    path("import_pg_pod/", ImportPgNode, name="import_pg_pod"),
    path("backup_pg_pod/", BackupPgNode, name="backup_pg_node"),
    path("restore_pg_pod/", RestoreBackupPgNode, name= "restore_pg_node"),
    path("add_pg_database_pod/", AddpgDB, name = "add_pg_database_pod"),
    path("export_pg_database_pod/", Exportk8sPgDatabase, name= "export_pg_database_pod"),
    path("check_pg_pod_database_name/", CheckPgDatabaseName, name = "check_pg_pod_database_name"),
    path("check_pg_pod_database_size/", CheckPgDatabaseSize, name = "check_pg_pod_database_size"),
    path("restore_k8s_pg_db/", RestoreBackupPgDB, name = "restore_k8s_pg_db"),
    path("drop_pg_database_pod/", DropPgDatabase, name = "drop_pg_database_pod"),

    #mongo
    path("create_mongo_master/", MongoClusterCreateView.as_view(), name="create_mongo_master"),
    path("drop_mongo_pod/", c123_k8s_DropMongoPodView, name="drop_mongo_pod"),
    path("dump_mongo_pod/", DumpMongoNode_k8s, name="dump_mongo_pod"),
    path("restore_dump_mongo_pod/", RestoreDumpMongoNode_k8s, name="restore_dump_mongo_pod"),
]
